# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2026 MOG Robotics OÜ.

"""Package type enum."""

from __future__ import annotations

from enum import Enum


class PackageType(Enum):
    """Package types."""

    WRAP = 'wrap'
