# SPDX-License-Identifier: Apache-2.0
# Copyright 2026 MOG Robotics OÜ

"""
File model submodule.
Contains classes representing only JSON files that collider itself generates or manages.
Can be loaded, saved, and validated against JSON.
"""
